summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--host/arch/x86/lib/crossystem_arch.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/host/arch/x86/lib/crossystem_arch.c b/host/arch/x86/lib/crossystem_arch.c
index 00c844b4..f39d31c5 100644
--- a/host/arch/x86/lib/crossystem_arch.c
+++ b/host/arch/x86/lib/crossystem_arch.c
@@ -193,11 +193,11 @@ int vb2_write_nv_storage(struct vb2_context *ctx)
if (0 != VbCmosWrite(offs, expectsz, ctx->nvdata))
return -1;
/* Also attempt to write using mosys if using vboot2 */
VbSharedDataHeader *sh = VbSharedDataRead();
if (sh) {
if (sh->flags & VBSD_BOOT_FIRMWARE_VBOOT2)
- vb2_write_nv_storage_mosys(ctx);
+ vb2_write_nv_storage_flashrom(ctx);
free(sh);
}
@@ -193,11 +193,11 @@ int vb2_write_nv_storage(struct vb2_context *ctx)
if (0 != VbCmosWrite(offs, expectsz, ctx->nvdata))
return -1;
- /* Also attempt to write using mosys if using vboot2 */
+ /* Also attempt to write using flashrom if using vboot2 */
VbSharedDataHeader *sh = VbSharedDataRead();
if (sh) {